@@ -12,7 +12,7 @@ use Plack::Util;
 use Kelp::Request;
 use Kelp::Response;
 
-our $VERSION = 0.9021;
+our $VERSION = 0.9051;
 
 # Basic attributes
 attr -host => hostname;
@@ -46,9 +46,9 @@ attr res => undef;
 sub new {
     my $self = shift->SUPER::new(@_);
 
-    # Always load these modules
-    $self->load_module( $self->config_module, extra => $self->__config );
-    $self->load_module('Routes');
+    # Always load these modules, but allow client to override
+    $self->_load_config();
+    $self->_load_routes();
 
     # Load the modules from the config
     if ( defined( my $modules = $self->config('modules') ) ) {
@@ -59,6 +59,16 @@ sub new {
     return $self;
 }
 
+sub _load_config {
+    my $self = shift;
+    $self->load_module( $self->config_module, extra => $self->__config );
+}
+
+sub _load_routes {
+    my $self = shift;
+    $self->load_module('Routes');
+}
+
 # Create a shallow copy of the app, optionally blessed into a
 # different subclass.
 sub _clone {
@@ -209,7 +219,10 @@ sub psgi {
         $self->logger( 'critical', $message ) if $self->can('logger');
 
         # Render 500
-        $self->res->render_500($message);
+        # Force stringificaion to avoid possible exception in class
+        # JSONization, which in case of fail will become null, but that
+        # is useless
+        $self->res->render_500("$message");
         $self->finalize;
     };
 }
@@ -875,7 +888,7 @@ At this point we are ready to send requests to the app via the
 L<request|Kelp::Test/request> method. It takes only one argument, an
 HTTP::Request object. It is very convenient to use the L<HTTP::Request::Common>
 module here, because you can create common requests using abridged syntax,
-i.e. C<GET>, C<POST>, etc.  The line C<$t-E<gt>request( GET '/path' )> fist
+i.e. C<GET>, C<POST>, etc.  The line C<$t-E<gt>request( GET '/path' )> first
 creates a HTTP::Request GET object, and then passes it to the C<request> method.
 
 =cut
@@ -1065,7 +1078,7 @@ If we instruct our web application to load the C<JSON> module, it will have a
 new method C<json> which will be a link to the C<JSON> object initialized in the
 module.
 
-See more exampled and POD at L<Kelp::Module>.
+See more examples and POD at L<Kelp::Module>.
 
 =head3 How to load modules using the config
 
@@ -1120,8 +1133,8 @@ the C<loaded_modules> hash will look like this:
         JSON     => Kelp::Module::JSON=HASH(0x209d454)
     }
 
-This can come handy if your module does more than just registering a new method
-into the application. Then, you can use its object instance to do access that
+This can come in handy if your module does more than just registering a new method
+into the application. Then, you can use its object instance to access that
 additional functionality.
 
 
@@ -1144,7 +1157,7 @@ anything else. The charset could also be changed in the config files.
 =head2 long_error
 
 When a route dies, Kelp will by default display a short error message. Set this
-attribute to a true value, if you need to see a full stack trace of the error.
+attribute to a true value if you need to see a full stack trace of the error.
 The C<KELP_LONG_ERROR> environment variable can also set this attribute.
 
 =head2 req
@@ -1173,7 +1186,7 @@ contain a reference to the current L<Kelp::Response> instance.
 
 =head2 build
 
-On it's own the C<build> method doesn't do anything. It is called by the
+On its own, the C<build> method doesn't do anything. It is called by the
 constructor, so it can be overridden to add route destinations and
 initializations.
 
@@ -1204,7 +1217,7 @@ namespace.
     # Will look for and load Kelp::Module::Redis
 
 Options for the module may be specified after its name, or in the
-C<modules_init> hash in the config. The precedence is given to the
+C<modules_init> hash in the config. Precedence is given to the
 inline options.
 See L<Kelp::Module> for more information on making and using modules.
 
@@ -1226,7 +1239,7 @@ environment. You can override this method to use a custom request module.
 
 =head2 before_finalize
 
-Override this method, to modify the response object just before it gets
+Override this method to modify the response object just before it gets
 finalized.
 
     package MyApp;
@@ -1336,6 +1349,8 @@ Christian Froemmel (senfomat)
 
 Ivan Baidakou (basiliscos)
 
+roy-tate
+
 =head1 LICENSE
 
 This module and all the modules in this package are governed by the same license
