@@ -101,7 +101,21 @@ A reference to the Kelp application.
 
 =head2 stash
 
-An all use, utility hash to use to pass information between routes.
+Returns a hashref, which represents the stash of the current the request
+
+An all use, utility hash to use to pass information between routes. The stash
+is a concept originally conceived by the developers of L<Catalyst>. It's a hash
+that you can use to pass data from one route to another.
+
+    # put value into stash
+    $self->req->stash->{username} = app->authenticate();
+    # more convenient way
+    $self->stash->{username} = app->authenticate();
+
+    # get value from stash
+    return "Hello " . $self->req->stash->{username};
+    # more convenient way
+    return "Hello " . $self->stash('username');
 
 =head2 named
 
@@ -222,7 +236,7 @@ In your config file:
 
 =cut
 
-=item Delete session values
+=item Delete session value
 
     delete $self->req->session->{'useless'};
 
@@ -230,7 +244,7 @@ In your config file:
 
 =item Remove all session values
 
-    $self->req->session = {};
+    $self->req->session( {} );
 
 =cut
 
