@@ -8,6 +8,7 @@ use Test::Deep;
 use Carp;
 use Encode ();
 use HTTP::Cookies;
+use Try::Tiny;
 
 BEGIN {
     $ENV{KELP_TESTING} = 1;    # Set the ENV for testing
@@ -57,11 +58,15 @@ sub request {
 
 sub request_ok {
     my ( $self, $req, $test_name ) = @_;
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $self->request($req)->code_is( 200, $test_name );
 }
 
 sub code_is {
     my ( $self, $code, $test_name ) = @_;
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "Response code is $code";
     is $self->res->code, $code, $test_name;
 
@@ -75,6 +80,8 @@ sub code_is {
 
 sub code_isnt {
     my ( $self, $code, $test_name ) = @_;
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "Response code is not $code";
     isnt $self->res->code, $code, $test_name;
     return $self;
@@ -82,6 +89,8 @@ sub code_isnt {
 
 sub content_is {
     my ( $self, $value, $test_name ) = @_;
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "Content is '$value'";
     is Encode::decode( $self->app->charset, $self->res->content ), $value,
       $test_name;
@@ -90,6 +99,8 @@ sub content_is {
 
 sub content_isnt {
     my ( $self, $value, $test_name ) = @_;
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "Content is not '$value'";
     isnt Encode::decode( $self->app->charset, $self->res->content ), $value,
       $test_name;
@@ -98,6 +109,8 @@ sub content_isnt {
 
 sub content_like {
     my ( $self, $regexp, $test_name ) = @_;
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "Content matches $regexp";
     like Encode::decode( $self->app->charset, $self->res->content ), $regexp,
       $test_name;
@@ -106,6 +119,8 @@ sub content_like {
 
 sub content_unlike {
     my ( $self, $regexp, $test_name ) = @_;
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "Content does not match $regexp";
     unlike Encode::decode( $self->app->charset, $self->res->content ), $regexp,
       $test_name;
@@ -114,6 +129,8 @@ sub content_unlike {
 
 sub content_type_is {
     my ( $self, $value, $test_name ) = @_;
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "Content-Type is '$value'";
     is $self->res->content_type, $value, $test_name;
     return $self;
@@ -121,6 +138,8 @@ sub content_type_is {
 
 sub content_type_isnt {
     my ( $self, $value, $test_name ) = @_;
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "Content-Type is not '$value'";
     isnt $self->res->content_type, $value, $test_name;
     return $self;
@@ -128,6 +147,8 @@ sub content_type_isnt {
 
 sub header_is {
     my ( $self, $header, $value, $test_name ) = @_;
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "Header '$header' => '$value'";
     is $self->res->header($header), $value, $test_name
       || $self->diag_headers();
@@ -136,6 +157,8 @@ sub header_is {
 
 sub header_isnt {
     my ( $self, $header, $value, $test_name ) = @_;
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "Header '$header' is not '$value'";
     isnt $self->res->header($header), $value, $test_name
       || $self->diag_headers();
@@ -144,6 +167,8 @@ sub header_isnt {
 
 sub header_like {
     my ( $self, $header, $regexp, $test_name ) = @_;
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "Header '$header' =~ $regexp";
     like $self->res->header($header), $regexp, $test_name
       || $self->diag_headers();
@@ -152,19 +177,35 @@ sub header_like {
 
 sub header_unlike {
     my ( $self, $header, $regexp, $test_name ) = @_;
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "Header '$header' !~ $regexp";
     unlike $self->res->header($header), $regexp, $test_name
       || $self->diag_headers();
     return $self;
 }
 
+sub json_content {
+    my $self = shift;
+    fail "No JSON decoder" unless $self->app->can('json');
+    my $result;
+    try {
+        $result = $self->app->json->decode( $self->res->content );
+    }
+    catch {
+        fail("Poorly formatted JSON");
+    };
+    return $result;
+}
+
 sub json_cmp {
     my ( $self, $expected, $test_name ) = @_;
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "JSON structure matches";
-    fail "No JSON decoder" unless $self->app->can('json');
     like $self->res->header('content-type'), qr/json/, 'Content-Type is JSON'
       or return $self;
-    my $json = $self->app->json->decode( $self->res->content );
+    my $json = $self->json_content;
     cmp_deeply( $json, $expected, $test_name ) or diag explain $json;
     return $self;
 }
